/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.couponconfig.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.couponconfig.entity.CouponConfig;
import vip.xiaonuo.biz.modular.couponconfig.param.CouponConfigAddParam;
import vip.xiaonuo.biz.modular.couponconfig.param.CouponConfigEditParam;
import vip.xiaonuo.biz.modular.couponconfig.param.CouponConfigIdParam;
import vip.xiaonuo.biz.modular.couponconfig.param.CouponConfigPageParam;
import vip.xiaonuo.biz.modular.couponconfig.service.CouponConfigService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 蛋糕券配置控制器
 *
 * @author fanzherong
 * @date  2025/04/14 10:32
 */
@Tag(name = "蛋糕券配置控制器")
@RestController
@Validated
public class CouponConfigController {

    @Resource
    private CouponConfigService couponConfigService;

    /**
     * 获取蛋糕券配置分页
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "获取蛋糕券配置分页")
    @SaCheckPermission("/biz/couponconfig/page")
    @GetMapping("/biz/couponconfig/page")
    public CommonResult<Page<CouponConfig>> page(CouponConfigPageParam couponConfigPageParam) {
        return CommonResult.data(couponConfigService.page(couponConfigPageParam));
    }

    /**
     * 添加蛋糕券配置
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "添加蛋糕券配置")
    @CommonLog("添加蛋糕券配置")
    @PostMapping("/biz/couponconfig/add")
    public CommonResult<String> add(@RequestBody @Valid CouponConfigAddParam couponConfigAddParam) {
        couponConfigService.add(couponConfigAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑蛋糕券配置
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "编辑蛋糕券配置")
    @CommonLog("编辑蛋糕券配置")
    @PostMapping("/biz/couponconfig/edit")
    public CommonResult<String> edit(@RequestBody @Valid CouponConfigEditParam couponConfigEditParam) {
        couponConfigService.edit(couponConfigEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除蛋糕券配置
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "删除蛋糕券配置")
    @CommonLog("删除蛋糕券配置")
    @PostMapping("/biz/couponconfig/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<CouponConfigIdParam> couponConfigIdParamList) {
        couponConfigService.delete(couponConfigIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取蛋糕券配置详情
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "获取蛋糕券配置详情")
    @GetMapping("/biz/couponconfig/detail")
    public CommonResult<CouponConfig> detail(@Valid CouponConfigIdParam couponConfigIdParam) {
        return CommonResult.data(couponConfigService.detail(couponConfigIdParam));
    }

    /**
     * 获取蛋糕券配置列表
     *
     * @author fanzherong
     * @date  2025/04/14 10:32
     */
    @Operation(summary = "获取蛋糕券配置列表")
    @GetMapping("/biz/couponconfig/getList")
    public CommonResult<List<CouponConfig>> getList(CouponConfigPageParam couponConfigPageParam) {
        return CommonResult.data(couponConfigService.getList(couponConfigPageParam));
    }
}
